<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
	xmlns="http://www.w3.org/1999/xhtml"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:ws="http://www.ebenoit.info/data"
	xmlns:wsf="http://www.ebenoit.info/ext">


	<!-- *********************************************************************************************** -->
	<!-- * TEMPLATES THAT GENERATE THE SIDE BAR                                                        * -->
	<!-- *********************************************************************************************** -->

	<!-- Main side bar generator
	   -
	   - If the side bar is enabled, use the side bar template to generate it and call the side bar
	   - contents generator.
	  -->
	<xsl:template name="generate-side-bar">
		<xsl:if test="wsf:get-side-bar( string( $page ) )/ws:side-bar/ws:block">
			<xsl:call-template name="side-bar-template">
				<xsl:with-param name="blocks">
					<xsl:for-each select="wsf:get-side-bar( string( $page ) )/ws:side-bar/ws:block">
						<xsl:call-template name="generate-side-block" />
					</xsl:for-each>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>

	<!-- Side bar block generator
	   -
	   - Generates the various blocks for the side bar.
	  -->
	<xsl:template name="generate-side-block">
		<xsl:choose>

			<!-- Menu box -->
			<xsl:when test="@source = 'menu'">
				<xsl:call-template name="generate-menu-box" />
			</xsl:when>

			<!-- "On this page" menu box -->
			<xsl:when test="@source = 'on-this-page'">
				<xsl:call-template name="generate-page-menu-box" />
			</xsl:when>

			<!-- History box -->
			<xsl:when test="@source = 'site-history'">
				<xsl:call-template name="generate-history-box" />
			</xsl:when>

			<!-- RSS feeds -->
			<xsl:when test="@source = 'feeds'">
				<xsl:call-template name="generate-feeds-box" />
			</xsl:when>

			<!-- Breadcrumb -->
			<xsl:when test="@source = 'breadcrumb'">
				<xsl:call-template name="generate-breadcrumb-box" />
			</xsl:when>

			<!-- Language selector -->
			<xsl:when test="@source = 'language-selector'">
				<xsl:call-template name="side-box-template">
					<xsl:with-param name="id">language-box</xsl:with-param>
					<xsl:with-param name="title">
						<xsl:call-template name="get-i18n-string">
							<xsl:with-param name="id">language</xsl:with-param>
						</xsl:call-template>
					</xsl:with-param>
					<xsl:with-param name="contents">
						<xsl:call-template name="language-selector-template" />
					</xsl:with-param>
				</xsl:call-template>
			</xsl:when>

		</xsl:choose>
	</xsl:template>

</xsl:stylesheet>
